@@ -3,7 +3,6 @@ package GraphViz2::Marpa;
 use strict;
 use warnings;
 use warnings qw(FATAL utf8); # Fatalize encoding glitches.
-use open     qw(:std :utf8); # Undeclared streams in UTF-8.
 
 use GraphViz2::Marpa::Renderer::Graphviz;
 
@@ -181,7 +180,7 @@ has uid =>
 	required => 0,
 );
 
-our $VERSION = '2.03';
+our $VERSION = '2.04';
 
 # ------------------------------------------------
 
@@ -1691,7 +1690,7 @@ C<new()> is called as C<< my($g2m) = GraphViz2::Marpa -> new(k1 => v1, k2 => v2,
 It returns a new object of type C<GraphViz2::Marpa>.
 
 Key-value pairs accepted in the parameter list (see corresponding methods for details
-[e.g. L<description([$graph])>]):
+[e.g. L</description([$graph])>]):
 
 =over 4
 
@@ -1916,8 +1915,8 @@ Here, the [] indicate an optional parameter.
 
 Get or set the value used by the logger object.
 
-This option is only used if L<GraphViz2::Marpa:::Lexer> or L<GraphViz2::Marpa::Parser>
-use or create an object of type L<Log::Handler>. See L<Log::Handler::Levels>.
+This option is only used if an object of type L<Log::Handler> is ceated.
+See L<Log::Handler::Levels>.
 
 'maxlevel' is a parameter to L</new()>. See L</Constructor and Initialization> for details.
 
@@ -1927,8 +1926,8 @@ Here, the [] indicate an optional parameter.
 
 Get or set the value used by the logger object.
 
-This option is only used if L<GraphViz2::Marpa:::Lexer> or L<GraphViz2::Marpa::Parser>
-use or create an object of type L<Log::Handler>. See L<Log::Handler::Levels>.
+This option is only used if an object of type L<Log::Handler> is created.
+See L<Log::Handler::Levels>.
 
 'minlevel' is a parameter to L</new()>. See L</Constructor and Initialization> for details.
 
@@ -2429,7 +2428,7 @@ to provide analysis of the structure of the graph.
 
 =head1 Machine-Readable Change Log
 
-The file CHANGES was converted into Changelog.ini by L<Module::Metadata::Changes>.
+The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
 
 =head1 Version Numbers
 
@@ -2439,8 +2438,7 @@ Version numbers < 1.00 represent development versions. From 1.00 up, they are pr
 
 Many thanks are due to the people who worked on L<Graphviz|http://www.graphviz.org/>.
 
-Jeffrey Kegler wrote L<Marpa::XS>, and has a blog on it at
-L<http://blogs.perl.org/users/jeffrey_kegler/>.
+Jeffrey Kegler wrote Marpa and L<Marpa::R2>.
 
 And thanks to rns (Ruslan Shvedov) for writing the grammar for double-quoted strings used in
 L<MarpaX::Demo::SampleScripts>'s scripts/quoted.strings.02.pl. I adapted it to HTML (see
