@@ -3,7 +3,6 @@ package GraphViz2::Marpa::Utils;
 use strict;
 use warnings;
 use warnings qw(FATAL utf8); # Fatalize encoding glitches.
-use open     qw(:std :utf8); # Undeclared streams in UTF-8.
 
 use Algorithm::Diff;
 
@@ -18,7 +17,7 @@ use Moo;
 
 use Path::Tiny;
 
-our $VERSION = '2.03';
+our $VERSION = '2.04';
 
 # ------------------------------------------------
 
@@ -150,7 +149,7 @@ Used by scripts/test.html.pl and t/test.t.
 
 =head1 Machine-Readable Change Log
 
-The file CHANGES was converted into Changelog.ini by L<Module::Metadata::Changes>.
+The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
 
 =head1 Version Numbers
 
